==> haskell-infer-license-0.2.0-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-F7vOlm4LcE3FDWTe2jcXqh
key:                  infer-license-0.2.0-F7vOlm4LcE3FDWTe2jcXqh
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  0e8ad193b8db3d1a8657cd9e6753f23e
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/infer-license-0.2.0
hs-libraries:         HSinfer-license-0.2.0-F7vOlm4LcE3FDWTe2jcXqh
depends:
    base-4.14.1.0 directory-1.3.6.0 filepath-1.4.2.1 text-1.2.4.1
    text-metrics-0.3.0-9LqFzaIOuxsKUMEQaFC60d

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infer-license-0.2.0-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-Atj4CMmj73ILPFF7uxFAj2
key:                  infer-license-0.2.0-Atj4CMmj73ILPFF7uxFAj2
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  930c6210ee4264ca4b39f00d0e2a1883
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/infer-license-0.2.0
hs-libraries:         HSinfer-license-0.2.0-Atj4CMmj73ILPFF7uxFAj2
depends:
    base-4.14.1.0 directory-1.3.6.0 filepath-1.4.2.1 text-1.2.4.1
    text-metrics-0.3.0-8xVv2sCCh545ft3DrsdFJk

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
